==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/vpc/kotlin/inputs/GetSecurityGroupRulesFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpc.kotlin.inputs

import com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the field to filter by, as defined by
 * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupRules.html).
 * @property values Set of values that are accepted for the given field.
 * Security group rule IDs will be selected if any one of the given values match.
 */
public data class GetSecurityGroupRulesFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter> {
    override fun toJava(): com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter =
        com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetSecurityGroupRulesFilter].
 */
@PulumiTagMarker
public class GetSecurityGroupRulesFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the field to filter by, as defined by
     * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupRules.html).
     */
    @JvmName("walwgayksrfmrbku")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Set of values that are accepted for the given field.
     * Security group rule IDs will be selected if any one of the given values match.
     */
    @JvmName("shqaoxukgjafuxdd")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Set of values that are accepted for the given field.
     * Security group rule IDs will be selected if any one of the given values match.
     */
    @JvmName("uaffioochowjqasg")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetSecurityGroupRulesFilter = GetSecurityGroupRulesFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/vpc/kotlin/inputs/GetSecurityGroupRulesFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.vpc.kotlin.inputs

import com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the field to filter by, as defined by
 * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupRules.html).
 * @property values Set of values that are accepted for the given field.
 * Security group rule IDs will be selected if any one of the given values match.
 */
public data class GetSecurityGroupRulesFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter> {
    override fun toJava(): com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter =
        com.pulumi.aws.vpc.inputs.GetSecurityGroupRulesFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetSecurityGroupRulesFilter].
 */
@PulumiTagMarker
public class GetSecurityGroupRulesFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the field to filter by, as defined by
     * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupRules.html).
     */
    @JvmName("lsxrbagmqscvkdxd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Set of values that are accepted for the given field.
     * Security group rule IDs will be selected if any one of the given values match.
     */
    @JvmName("bwabtwkefrlmjrxt")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Set of values that are accepted for the given field.
     * Security group rule IDs will be selected if any one of the given values match.
     */
    @JvmName("pfbwofoqjpnmqpei")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetSecurityGroupRulesFilter = GetSecurityGroupRulesFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}
